Package: cubfits
Version: 0.1-4
Date: 2021-11-06
Title: Codon Usage Bias Fits
Authors@R: c(person("Wei-Chen", "Chen", role = c("aut", "cre"), email =
       "wccsnow@gmail.com"),
       person("Russell", "Zaretzki", role = "aut", email = "rzaretzk@utk.edu"),
       person("William", "Howell", role = "aut"),
       person("Cedric", "Landerer", role = "aut"),
       person("Drew", "Schmidt", role = "aut"),
       person("Michael A.", "Gilchrist", role = "aut", email = "mikeg@utk.edu"),
       person("Preston", "Hewgley", role = "ctb"),
       person("Students", "REU13", role = "ctb"))
Depends: R(>= 4.0.0), methods, coda, foreach, parallel, stats,
        graphics, utils
Suggests: seqinr, VGAM, EMCluster
Enhances: pbdMPI (>= 0.3-1)
LazyLoad: yes
LazyData: yes
Description: Estimating mutation and selection coefficients on synonymous
       codon bias usage based on models of ribosome overhead cost (ROC).
       Multinomial logistic regression and Markov Chain Monte Carlo are used to
       estimate and predict protein production rates with/without the presence
       of expressions and measurement errors. Work flows with examples for
       simulation, estimation and prediction processes are also provided
       with parallelization speedup. The whole framework is tested with
       yeast genome and gene expression data of Yassour, et al. (2009)
       <doi:10.1073/pnas.0812841106>.
License: Mozilla Public License 2.0
BugReports: https://github.com/snoweye/cubfits/issues
URL: https://github.com/snoweye/cubfits
NeedsCompilation: yes
Maintainer: Wei-Chen Chen <wccsnow@gmail.com>
Packaged: 2021-11-07 01:53:23 UTC; snoweye
Author: Wei-Chen Chen [aut, cre],
  Russell Zaretzki [aut],
  William Howell [aut],
  Cedric Landerer [aut],
  Drew Schmidt [aut],
  Michael A. Gilchrist [aut],
  Preston Hewgley [ctb],
  Students REU13 [ctb]
Repository: CRAN
Date/Publication: 2021-11-07 17:20:02 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 00:19:51 UTC; unix
Archs: cubfits.so.dSYM
